@@ -31,42 +31,60 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-// Get Option and Defautl to com_groups
-$option = JRequest::getCmd('option', 'com_groups');
+error_reporting(E_ALL);
+@ini_set('display_errors', '1');
 
-if (!JFactory::getUser()->authorise('core.manage', $option))
+if (version_compare(JVERSION, '1.6', 'lt'))
 {
-	return JError::raiseWarning(404, JText::_('JERROR_ALERTNOAUTHOR'));
+	$jacl = JFactory::getACL();
+	$jacl->addACL($option, 'admin', 'users', 'super administrator');
+	$jacl->addACL($option, 'manage', 'users', 'super administrator');
+	$jacl->addACL($option, 'manage', 'users', 'administrator');
+	$jacl->addACL($option, 'manage', 'users', 'manager');
+
+	// Authorization check
+	$user = JFactory::getUser();
+	if (!$user->authorize($option, 'manage'))
+	{
+		$app = JFactory::getApplication();
+		$app->redirect('index.php', JText::_('ALERTNOTAUTH'));
+	}
+}
+else 
+{
+	if (!JFactory::getUser()->authorise('core.manage', $option)) 
+	{
+		return JError::raiseWarning(404, JText::_('JERROR_ALERTNOAUTHOR'));
+	}
+
+	require_once(JPATH_COMPONENT . DS . 'models' . DS . 'group.php');
+	require_once(JPATH_COMPONENT . DS . 'tables' . DS . 'group.php');
 }
 
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'models' . DS . 'group.php');
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'group.php');
+// Include scripts
+require_once(JPATH_COMPONENT . DS . 'helpers' . DS . 'groups.php');
+require_once(JPATH_COMPONENT . DS . 'tables' . DS . 'log.php');
+require_once(JPATH_COMPONENT . DS . 'tables' . DS . 'reason.php');
+require_once(JPATH_COMPONENT . DS . 'tables' . DS . 'pages.php');
 
-// Include tables
-require_once JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'reason.php';
+//Hubzero Libraries
+ximport('Hubzero_Group');
+ximport('Hubzero_Group_Helper');
+ximport('Hubzero_User_Helper');
 
-// include models
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'tags.php';
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'log' . DS . 'archive.php';
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'page' . DS . 'archive.php';
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'module' . DS . 'archive.php';
-
-// Include Helpers
-require_once JPATH_COMPONENT_ADMINISTRATOR . DS . 'helpers' . DS . 'groups.php';
-require_once JPATH_COMPONENT_ADMINISTRATOR . DS . 'helpers' . DS . 'gitlab.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'view.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'pages.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'document.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'template.php';
-
-// build controller path
 $controllerName = JRequest::getCmd('controller', 'manage');
-if (!file_exists(JPATH_COMPONENT_ADMINISTRATOR . DS . 'controllers' . DS . $controllerName . '.php'))
+if (!file_exists(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php'))
 {
 	$controllerName = 'manage';
 }
 
-require_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'controllers' . DS . $controllerName . '.php');
+JSubMenuHelper::addEntry(
+	JText::_('Manage'), 
+	'index.php?option=' .  $option . '&controller=manage', 
+	$controllerName == 'manage'
+);
+
+require_once(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php');
 $controllerName = 'GroupsController' . ucfirst($controllerName);
 
 // Instantiate controller
