@@ -31,50 +31,28 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Manage members password rules
  */
-class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
+class MembersControllerPasswordRules extends Hubzero_Controller
 {
 	/**
 	 * Display a list of password rules
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function displayTask()
 	{
 		// Get configuration
 		$config = JFactory::getConfig();
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		// Incoming
-		$this->view->filters = array(
-			'limit' => $app->getUserStateFromRequest(
-				$this->_option . '.' . $this->_controller . '.limit',
-				'limit',
-				$config->getValue('config.list_limit'),
-				'int'
-			),
-			'start' => $app->getUserStateFromRequest(
-				$this->_option . '.' . $this->_controller . '.limitstart',
-				'limitstart',
-				0,
-				'int'
-			),
-			'sort' => $app->getUserStateFromRequest(
-				$this->_option . '.' . $this->_controller . '.sort',
-				'filter_order',
-				'ordering'
-			),
-			'sort_Dir' => $app->getUserStateFromRequest(
-				$this->_option . '.' . $this->_controller . '.sort_Dir',
-				'filter_order_Dir',
-				'ASC'
-			)
-		);
-		// In case limit has been changed, adjust limitstart accordingly
-		$this->view->filters['start'] = ($this->view->filters['limit'] != 0 ? (floor($this->view->filters['start'] / $this->view->filters['limit']) * $this->view->filters['limit']) : 0);
-
+		$this->view->filters = array();
+		$this->view->filters['limit'] = $app->getUserStateFromRequest($this->_option . '.' . $this->_controller . '.limit', 'limit', $config->getValue('config.list_limit'), 'int');
+		$this->view->filters['start'] = $app->getUserStateFromRequest($this->_option . '.' . $this->_controller . '.limitstart', 'limitstart', 0, 'int');
 
 		// Get password rules object
 		$prObj = new MembersPasswordRules($this->database);
@@ -83,7 +61,7 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		$this->view->total = $prObj->getCount($this->view->filters);
 
 		// If count is zero, i.e. no records, let's add some default password rules
-		if ($this->view->total == 0)
+		if($this->view->total == 0)
 		{
 			// Add default rules if we don't have any already
 			$prObj->defaultContent();
@@ -97,16 +75,12 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 		// Initiate pagination
 		jimport('joomla.html.pagination');
-		$this->view->pageNav = new JPagination(
-			$this->view->total,
-			$this->view->filters['start'],
-			$this->view->filters['limit']
-		);
+		$this->view->pageNav = new JPagination($this->view->total, $this->view->filters['start'], $this->view->filters['limit']);
 
 		// Set any errors
-		foreach ($this->getErrors() as $error)
+		if ($this->getError())
 		{
-			$this->view->setError($error);
+			$this->view->setError($this->getError());
 		}
 
 		// Output the HTML
@@ -115,7 +89,7 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 	/**
 	 * Create a new password rule
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function addTask()
@@ -126,23 +100,27 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit a password rule
-	 *
+	 * 
 	 * @param      integer $id ID of member to edit
 	 * @return     void
 	 */
 	public function editTask($id=0)
 	{
-		JRequest::setVar('hidemainmenu', 1);
+		$this->view->setLayout('edit');
 
 		if (!$id)
 		{
 			// Incoming
-			$id = JRequest::getVar('id', array());
+			$ids = JRequest::getVar('id', array());
 
 			// Get the single ID we're working with
-			if (is_array($id))
+			if (is_array($ids))
 			{
-				$id = (!empty($id)) ? $id[0] : 0;
+				$id = (!empty($ids)) ? $ids[0] : 0;
+			}
+			else
+			{
+				$id = 0;
 			}
 		}
 
@@ -153,21 +131,19 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		$this->view->rules_list = $this->rulesList($this->view->row->rule);
 
 		// Set any errors
-		foreach ($this->getErrors() as $error)
+		if ($this->getError())
 		{
-			$this->view->setError($error);
+			$this->view->setError($this->getError());
 		}
 
 		// Output the HTML
-		$this->view
-			->setLayout('edit')
-			->display();
+		$this->view->display();
 	}
 
 	/**
 	 * Apply changes to a password rule
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function applyTask()
 	{
@@ -177,15 +153,15 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save password rule
-	 *
-	 * @param   integer  $redirect  Whether or not to redirect after save
-	 * @return  void
+	 * 
+	 * @param      integer $redirect - whether or not to redirect after save
+	 * @return     boolean Return description (if any) ...
 	 */
 	public function saveTask($redirect=1)
 	{
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
-
+		
 		// Incoming password rule edits
 		$fields = JRequest::getVar('fields', array(), 'post');
 
@@ -205,12 +181,13 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 			// Redirect
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_MEMBERS_PASSWORD_RULES_SAVE_SUCCESS'),
+				JText::_('PASSWORD_RULES_SAVE_SUCCESS'),
 				'message'
 			);
-		}
-		else
+		} 
+		else 
 		{
+			$this->view->setLayout('edit');
 			$this->view->task = 'edit';
 			$this->editTask($fields['id']);
 		}
@@ -218,8 +195,8 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 	/**
 	 * Order up
-	 *
-	 * @return  void
+	 * 
+	 * @return void
 	 */
 	public function orderupTask()
 	{
@@ -231,14 +208,14 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		// Output message and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_MEMBERS_PASSWORD_RULES_ORDERING_SAVED')
+			JText::_('PASSWORD_RULES_ORDERING_SAVED')
 		);
 	}
 
 	/**
 	 * Order down
-	 *
-	 * @return  void
+	 * 
+	 * @return void
 	 */
 	public function orderdownTask()
 	{
@@ -250,15 +227,15 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		// Output message and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_MEMBERS_PASSWORD_RULES_ORDERING_SAVED')
+			JText::_('PASSWORD_RULES_ORDERING_SAVED')
 		);
 	}
 
 	/**
 	 * Reorder rules
-	 *
-	 * @param   integer  $up  Whether order up or down
-	 * @return  void
+	 * 
+	 * @param      integer $up - whether order up or down
+	 * @return     void
 	 */
 	public function orderTask($up)
 	{
@@ -275,8 +252,8 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save order
-	 *
-	 * @return  void
+	 * 
+	 * @return void
 	 */
 	public function saveorderTask()
 	{
@@ -312,22 +289,22 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		// Output message and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_MEMBERS_PASSWORD_RULES_ORDERING_SAVED')
+			JText::_('PASSWORD_RULES_ORDERING_SAVED')
 		);
 	}
 
 	/**
 	 * Toggle a password rule between enabled and disabled
-	 *
-	 * @return  void
+	 * 
+	 * @return void
 	 */
 	public function toggle_enabledTask()
 	{
 		// Incoming (we're expecting an array)
 		$ids = JRequest::getVar('id', array());
-		if (!is_array($ids))
+		if (!is_array($ids)) 
 		{
-			$ids = array($ids);
+			$ids = array(0);
 		}
 
 		// Loop through the IDs
@@ -350,14 +327,14 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		// Output message and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_MEMBERS_PASSWORD_RULES_TOGGLE_ENABLED')
+			JText::_('PASSWORD_RULES_TOGGLE_ENABLED')
 		);
 	}
 
 	/**
 	 * Restore default password rules (found in password_rules table class)
-	 *
-	 * @return  void
+	 * 
+	 * @return void
 	 */
 	public function restore_default_contentTask()
 	{
@@ -370,14 +347,14 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		// Output message and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_MEMBERS_PASSWORD_RULES_RESTORED')
+			JText::_('PASSWORD_RULES_RESTORED')
 		);
 	}
 
 	/**
 	 * Removes [a] password rule(s)
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function removeTask()
 	{
@@ -386,10 +363,6 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 
 		// Incoming
 		$ids = JRequest::getVar('id', array());
-		if (!is_array($ids))
-		{
-			$ids = array($ids);
-		}
 
 		// Do we have any IDs?
 		if (!empty($ids))
@@ -410,7 +383,7 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 			// Output message and redirect
 			$this->setRedirect(
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-				JText::_('COM_MEMBERS_PASSWORD_RULES_DELETE_NO_ROW_SELECTED'),
+				JText::_('PASSWORD_RULES_DELETE_NO_ROW_SELECTED'),
 				'warning'
 			);
 		}
@@ -418,38 +391,36 @@ class MembersControllerPasswordRules extends \Hubzero\Component\AdminController
 		// Output messsage and redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('COM_MEMBERS_PASSWORD_RULES_DELETE_SUCCESS')
+			JText::_('PASSWORD_RULES_DELETE_SUCCESS')
 		);
 	}
 
 	/**
 	 * Cancel a task (redirects to default task)
 	 *
-	 * @return  void
+	 * @return     void
 	 */
 	public function cancelTask()
 	{
-		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller
-		);
+		$this->_redirect = 'index.php?option=' . $this->_option . '&controller=' . $this->_controller;
 	}
 
 	/**
 	 * Build rules select list
 	 *
-	 * @return  void
+	 * @return     void
 	 */
 	public function rulesList($current_rule='')
 	{
-		$rules[] = JHTML::_('select.option', 'minClassCharacters',  'minClassCharacters',  'value', 'text');
-		$rules[] = JHTML::_('select.option', 'minPasswordLength',   'minPasswordLength',   'value', 'text');
-		$rules[] = JHTML::_('select.option', 'maxPasswordLength',   'maxPasswordLength',   'value', 'text');
-		$rules[] = JHTML::_('select.option', 'minUniqueCharacters', 'minUniqueCharacters', 'value', 'text');
-		$rules[] = JHTML::_('select.option', 'notBlacklisted',      'notBlacklisted',      'value', 'text');
-		$rules[] = JHTML::_('select.option', 'notNameBased',        'notNameBased',        'value', 'text');
-		$rules[] = JHTML::_('select.option', 'notUsernameBased',    'notUsernameBased',    'value', 'text');
-		$rules[] = JHTML::_('select.option', 'notReused',           'notReused',           'value', 'text');
-		$rules[] = JHTML::_('select.option', 'notStale',            'notStale',            'value', 'text');
+		$rules[] = JHTML::_('select.option', 'minClassCharacters',  JText::_('minClassCharacters'),  'value', 'text');
+		$rules[] = JHTML::_('select.option', 'minPasswordLength',   JText::_('minPasswordLength'),   'value', 'text');
+		$rules[] = JHTML::_('select.option', 'maxPasswordLength',   JText::_('maxPasswordLength'),   'value', 'text');
+		$rules[] = JHTML::_('select.option', 'minUniqueCharacters', JText::_('minUniqueCharacters'), 'value', 'text');
+		$rules[] = JHTML::_('select.option', 'notBlacklisted',      JText::_('notBlacklisted'),      'value', 'text');
+		$rules[] = JHTML::_('select.option', 'notNameBased',        JText::_('notNameBased'),        'value', 'text');
+		$rules[] = JHTML::_('select.option', 'notUsernameBased',    JText::_('notUsernameBased'),    'value', 'text');
+		$rules[] = JHTML::_('select.option', 'notReused',           JText::_('notReused'),           'value', 'text');
+		$rules[] = JHTML::_('select.option', 'notStale',            JText::_('notStale'),            'value', 'text');
 
 		$rselected = $current_rule;
 
