@@ -39,108 +39,125 @@ class ForumCategory extends JTable
 	/**
 	 * int(11) Primary key
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $id         = NULL;
 
 	/**
 	 * varchar(255)
 	 * 
-	 * @var unknown
+	 * @var string
 	 */
 	var $title      = NULL;
 	
 	/**
 	 * varchar(255)
 	 * 
-	 * @var unknown
+	 * @var string
 	 */
 	var $alias      = NULL;
 
 	/**
 	 * text
 	 * 
-	 * @var unknown
+	 * @var string
 	 */
 	var $description    = NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
 	 * 
-	 * @var unknown
+	 * @var string
 	 */
 	var $created    = NULL;
 
 	/**
 	 * int(11)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $created_by = NULL;
 
 	/**
 	 * datetime (0000-00-00 00:00:00)
 	 * 
-	 * @var unknown
+	 * @var string
 	 */
 	var $modified   = NULL;
 
 	/**
 	 * int(11)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $modified_by = NULL;
 
 	/**
 	 * int(2)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $state      = NULL;
 
 	/**
 	 * int(11)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $hits       = NULL;
 
+	/**
+	 * varchar(100)
+	 * 
+	 * @var string
+	 */
+	var $scope = NULL;
+
 	/**
 	 * int(11)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
-	var $group_id = NULL;
+	var $scope_id = NULL;
 
 	/**
 	 * tinyint(2)  0=public, 1=registered, 2=special, 3=protected, 4=private
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $access     = NULL;
 	
 	/**
 	 * int(11)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $section_id = NULL;
 	
 	/**
 	 * tinyint(2)
 	 * 
-	 * @var unknown
+	 * @var integer
 	 */
 	var $closed = null;
 	
 	/**
+	 * int(11)
 	 * ID for ACL asset (J1.6+)
 	 * 
-	 * @var int(11)
+	 * @var integer
 	 */
 	var $asset_id = NULL;
 
+	/**
+	 * int(11)
+	 * Used to associate another object such as a 
+	 * course lecture to a specific entry
+	 * 
+	 * @var integer
+	 */
+	var $object_id = NULL;
+
 	/**
 	 * Constructor
 	 * 
@@ -193,12 +210,12 @@ class ForumCategory extends JTable
 	{
 		// Initialise variables.
 		$assetId = null;
-		$db		= $this->getDbo();
+		$db = $this->getDbo();
 
 		if ($assetId === null) 
 		{
 			// Build the query to get the asset id for the parent category.
-			$query	= $db->getQuery(true);
+			$query = $db->getQuery(true);
 			$query->select('id');
 			$query->from('#__assets');
 			$query->where('name = ' . $db->quote('com_forum'));
@@ -228,7 +245,7 @@ class ForumCategory extends JTable
 	 * @param      string $oid Record alias
 	 * @return     boolean True on success
 	 */
-	public function loadByAlias($oid=NULL, $section_id=null, $group_id=null)
+	public function loadByAlias($oid=NULL, $section_id=null, $scope_id=null, $scope='site')
 	{
 		if ($oid === NULL) 
 		{
@@ -236,14 +253,50 @@ class ForumCategory extends JTable
 		}
 		$oid = trim($oid);
 		
-		$query = "SELECT * FROM $this->_tbl WHERE alias='$oid'";
+		$query = "SELECT * FROM $this->_tbl WHERE alias=" . $this->_db->Quote($oid);
 		if ($section_id !== null)
 		{
-			$query .= " AND section_id=" . $section_id;
+			$query .= " AND section_id=" . $this->_db->Quote($section_id);
 		}
-		if ($group_id !== null)
+		if ($scope_id !== null)
 		{
-			$query .= " AND group_id=" . $group_id;
+			$query .= " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope);
+		}
+
+		$this->_db->setQuery($query);
+		if ($result = $this->_db->loadAssoc()) 
+		{
+			return $this->bind($result);
+		} 
+		else 
+		{
+			$this->setError($this->_db->getErrorMsg());
+			return false;
+		}
+	}
+
+	/**
+	 * Load a record by its alias and bind data to $this
+	 * 
+	 * @param      string $oid Record alias
+	 * @return     boolean True upon success, False if errors
+	 */
+	public function loadByObject($oid=NULL, $section_id=null, $scope_id=null, $scope='site')
+	{
+		if ($oid === NULL) 
+		{
+			return false;
+		}
+		$oid = intval($oid);
+
+		$query = "SELECT * FROM $this->_tbl WHERE object_id=" . $this->_db->Quote($oid);
+		if ($section_id !== null)
+		{
+			$query .= " AND section_id=" . $this->_db->Quote($section_id);
+		}
+		if ($scope_id !== null)
+		{
+			$query .= " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope);
 		}
 
 		$this->_db->setQuery($query);
@@ -264,21 +317,22 @@ class ForumCategory extends JTable
 	 * @param      integer $group ID of group the data belongs to
 	 * @return     boolean True if data is bound to $this object
 	 */
-	public function loadDefault($group=0)
+	public function loadDefault($scope_id=0, $scope='site')
 	{
 		$result = array(
-			'id' => 0,
-			'title' => JText::_('Discussions'),
+			'id'          => 0,
+			'title'       => JText::_('Discussions'),
 			'description' => JText::_('Default category for all discussions in this forum.'),
-			'section_id' => 0,
-			'created_by' => 0,
-			'group_id' => $group,
-			'state' => 1,
-			'access' => 1
+			'section_id'  => 0,
+			'created_by'  => 0,
+			'scope'       => $scope,
+			'scope_id'    => $scope_id,
+			'state'       => 1,
+			'access'      => 1
 		);
 		$result['alias'] = str_replace(' ', '-', $result['title']);
 		$result['alias'] = preg_replace("/[^a-zA-Z0-9\-]/", '', strtolower($result['alias']));
-		
+
 		return $this->bind($result);
 	}
 
@@ -290,19 +344,22 @@ class ForumCategory extends JTable
 	public function check()
 	{
 		$this->title = trim($this->title);
-		
+
 		if (!$this->title) 
 		{
 			$this->setError(JText::_('Please provide a title.'));
 			return false;
 		}
-		
+
 		if (!$this->alias)
 		{
 			$this->alias = str_replace(' ', '-', strtolower($this->title));
 		}
 		$this->alias = preg_replace("/[^a-zA-Z0-9\-]/", '', $this->alias);
-		
+
+		$this->scope = preg_replace("/[^a-zA-Z0-9]/", '', strtolower($this->scope));
+		$this->scope_id = intval($this->scope_id);
+
 		$juser =& JFactory::getUser();
 		if (!$this->id)
 		{
@@ -314,7 +371,7 @@ class ForumCategory extends JTable
 			$this->modified = date('Y-m-d H:i:s', time());
 			$this->modified_by = $juser->get('id');
 		}
-		
+
 		return true;
 	}
 
@@ -327,7 +384,10 @@ class ForumCategory extends JTable
 	protected function _buildQuery($filters=array())
 	{
 		$query  = "FROM $this->_tbl AS c";
-		$query .= " LEFT JOIN #__xgroups AS g ON g.gidNumber=c.group_id";
+		if (isset($filters['group']) && (int) $filters['group'] >= 0) 
+		{
+			$query .= " LEFT JOIN #__xgroups AS g ON g.gidNumber=c.scope_id";
+		}
 		if (version_compare(JVERSION, '1.6', 'lt'))
 		{
 			$query .= " LEFT JOIN #__groups AS a ON c.access=a.id";
@@ -348,12 +408,24 @@ class ForumCategory extends JTable
 		}
 		if (isset($filters['group']) && (int) $filters['group'] >= 0) 
 		{
-			$where[] = "c.group_id=" . $this->_db->Quote(intval($filters['group']));
+			$where[] = "(c.scope_id=" . $this->_db->Quote(intval($filters['group'])) . " AND c.scope=" . $this->_db->Quote('group') . ")";
+		}
+		if (isset($filters['scope']) && (string) $filters['scope']) 
+		{
+			$where[] = "c.scope=" . $this->_db->Quote(strtolower($filters['scope']));
+		}
+		if (isset($filters['scope_id']) && (int) $filters['scope_id'] >= 0) 
+		{
+			$where[] = "c.scope_id=" . $this->_db->Quote(intval($filters['scope_id']));
 		}
 		if (isset($filters['section_id']) && (int) $filters['section_id'] >= 0) 
 		{
 			$where[] = "c.section_id=" . $this->_db->Quote(intval($filters['section_id']));
 		}
+		if (isset($filters['object_id']) && (int) $filters['object_id'] >= 0) 
+		{
+			$where[] = "c.object_id=" . $this->_db->Quote(intval($filters['object_id']));
+		}
 		if (isset($filters['search']) && $filters['search'] != '') 
 		{
 			$where[] = "(LOWER(c.title) LIKE '%" . $this->_db->getEscaped(strtolower($filters['search'])) . "%' 
@@ -395,14 +467,22 @@ class ForumCategory extends JTable
 	{
 		if (isset($filters['admin']))
 		{
-			$query  = "SELECT c.*, g.cn AS group_alias, 
-						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0) AS threads,
+			$query  = "SELECT c.*";
+			if (isset($filters['group']) && (int) $filters['group'] >= 0) 
+			{
+				$query .= ", g.cn AS group_alias";
+			}
+			$query .= ", (SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0) AS threads,
 						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id) AS posts";
 		}
 		else 
 		{
-			$query  = "SELECT c.*, g.cn AS group_alias, 
-						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0 AND r.state=1) AS threads,
+			$query  = "SELECT c.*";
+			if (isset($filters['group']) && (int) $filters['group'] >= 0) 
+			{
+				$query .= ", g.cn AS group_alias";
+			}
+			$query .= ", (SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.parent=0 AND r.state=1) AS threads,
 						(SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=c.id AND r.state=1) AS posts";
 		}
 		if (version_compare(JVERSION, '1.6', 'lt'))
@@ -441,7 +521,7 @@ class ForumCategory extends JTable
 	 * @param      integer $group_id Group ID
 	 * @return     array
 	 */
-	public function getThreadCount($oid=null, $group_id=0)
+	public function getThreadCount($oid=null, $scope_id=0, $scope='site')
 	{
 		$k = $this->_tbl_key;
 		if ($oid !== null) 
@@ -449,7 +529,7 @@ class ForumCategory extends JTable
 			$this->$k = intval($oid);
 		}
 
-		$query = "SELECT COUNT(*) FROM #__forum_posts WHERE category_id=" . $this->$k . " AND group_id=$group_id AND parent=0 AND state < 2";
+		$query = "SELECT COUNT(*) FROM #__forum_posts WHERE category_id=" . $this->_db->Quote($this->$k) . " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope) . " AND parent=0 AND state < 2";
 
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
@@ -462,7 +542,7 @@ class ForumCategory extends JTable
 	 * @param      integer $group_id Group ID
 	 * @return     array
 	 */
-	public function getPostCount($oid=null, $group_id=0)
+	public function getPostCount($oid=null, $scope_id=0, $scope='site')
 	{
 		$k = $this->_tbl_key;
 		if ($oid !== null) 
@@ -471,7 +551,7 @@ class ForumCategory extends JTable
 		}
 
 		//$query = "SELECT COUNT(*) FROM #__forum_posts WHERE parent IN (SELECT r.id FROM #__forum_posts AS r WHERE r.category_id=" . $this->$k . " AND group_id=$group_id AND parent=0 AND state < 2)";
-		$query = "SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=" . $this->$k . " AND group_id=$group_id AND parent=0 AND state < 2";
+		$query = "SELECT COUNT(*) FROM #__forum_posts AS r WHERE r.category_id=" . $this->_db->Quote($this->$k) . " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope) . " AND parent=0 AND state < 2";
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
 	}
@@ -528,7 +608,7 @@ class ForumCategory extends JTable
 			$section = intval($section);
 		}
 		
-		$this->_db->setQuery("UPDATE $this->_tbl SET state=$state WHERE section_id IN ($section)");
+		$this->_db->setQuery("UPDATE $this->_tbl SET state=" . $this->_db->Quote($state) . " WHERE section_id IN ($section)");
 		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
