@@ -31,10 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
- * Primary component controller (extends \Hubzero\Component\SiteController)
+ * Primary component controller (extends Hubzero_Controller)
  */
-class TimeController extends \Hubzero\Component\SiteController
+class TimeController extends Hubzero_Controller
 {
 	/**
 	 * Execute function
@@ -106,8 +108,8 @@ class TimeController extends \Hubzero\Component\SiteController
 	 */
 	protected function _getTimeStyles()
 	{
-		$doc       = JFactory::getDocument();
-		$mainframe = JFactory::getApplication();
+		$doc       =& JFactory::getDocument();
+		$mainframe =& JFactory::getApplication();
 		$template  = $mainframe->getTemplate();
 		$task      = $this->_task;
 
@@ -140,7 +142,7 @@ class TimeController extends \Hubzero\Component\SiteController
 	 */
 	protected function _getTimeScripts()
 	{
-		$doc = JFactory::getDocument();
+		$doc =& JFactory::getDocument();
 
 		$component_js = "/components".DS."com_time".DS."time.jquery.js";
 		$hover_intent = DS . 'media' . DS . 'system' . DS . 'js' . DS . 'jquery.hoverIntent.js';
@@ -164,8 +166,6 @@ class TimeController extends \Hubzero\Component\SiteController
 		{
 			$this->_getScripts();
 		}
-
-		\Hubzero\Document\Assets::addSystemScript('jquery.infinitescroll');
 	}
 
 	/**
@@ -176,8 +176,8 @@ class TimeController extends \Hubzero\Component\SiteController
 	protected function _buildPathway()
 	{
 		//$option = substr($this->_option,4);
-		$app = JFactory::getApplication();
-		$pathway = $app->getPathway();
+		$app =& JFactory::getApplication();
+		$pathway =& $app->getPathway();
 
 		if (count($pathway->getPathWay()) <= 0)
 		{
@@ -213,7 +213,7 @@ class TimeController extends \Hubzero\Component\SiteController
 		$this->_title = JText::_(strtoupper($this->_option));
 
 		// Set the title of the browser window
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->_title);
 	}
 
@@ -257,7 +257,7 @@ class TimeController extends \Hubzero\Component\SiteController
 
 		// Get time plugins
 		JPluginHelper::importPlugin('time');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		// Trigger the functions that return the areas we'll be using
 		$time_plugins = $dispatcher->trigger('onTimeAreas', array());
@@ -291,7 +291,7 @@ class TimeController extends \Hubzero\Component\SiteController
 	{
 		// Get time plugins
 		JPluginHelper::importPlugin('time');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		// Trigger the functions that return the areas we'll be using
 		$time_plugins = $dispatcher->trigger('onTimeAreas', array());
@@ -329,7 +329,7 @@ class TimeController extends \Hubzero\Component\SiteController
 		$accessgroup = isset($this->config->parameters['accessgroup']) ? trim($this->config->parameters['accessgroup']) : 'time';
 
 		// Check if they're a member of admin group
-		$ugs = \Hubzero\User\Helper::getGroups($this->juser->get('id'));
+		$ugs = Hubzero_User_Helper::getGroups($this->juser->get('id'));
 		if ($ugs && count($ugs) > 0)
 		{
 			foreach ($ugs as $ug)
