@@ -31,6 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Tool classes
  */
@@ -52,11 +54,11 @@ require_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'helpe
 /**
  * Controller class for contributing a tool
  */
-class ToolsControllerResource extends \Hubzero\Component\SiteController
+class ToolsControllerResource extends Hubzero_Controller
 {
 	/**
 	 * Determines task being called and attempts to execute it
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
@@ -64,7 +66,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$this->_authorize();
 
 		// Load the com_resources component config
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 		$this->rconfig = $rconfig;
 
 		parent::execute();
@@ -72,11 +74,13 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display forms for editing/creating a reosurce
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function displayTask()
 	{
+		ximport('Hubzero_Tool_Version');
+
 		// Incoming
 		$alias   = JRequest::getVar('app', '');
 		$version = JRequest::getVar('editversion', 'dev');
@@ -86,7 +90,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$obj = new Tool($this->database);
 		$this->_toolid = $obj->getToolId($alias);
 
-		if (!$this->_toolid)
+		if (!$this->_toolid) 
 		{
 			$this->setRedirect(
 				JRoute::_('index.php?option=' . $this->_option . '&controller=pipeline')
@@ -95,9 +99,9 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		}
 
 		// make sure user is authorized to go further
-		if (!$this->_checkAccess($this->_toolid))
+		if (!$this->_checkAccess($this->_toolid)) 
 		{
-			JError::raiseError(403, JText::_('COM_TOOLS_ALERTNOTAUTH'));
+			JError::raiseError(403, JText::_('ALERTNOTAUTH'));
 			return;
 		}
 
@@ -110,37 +114,30 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$row = new ResourcesResource($this->database);
 		$row->loadAlias($alias);
 		$row->alias = ($row->alias) ? $row->alias : $alias;
-		if (!$status['fulltxt'])
-		{
+		if (!$status['fulltxt']) 
+		{ 
 			$status['fulltxt'] = $row->fulltxt;
 		}
 
 		// process first step
-		if ($nextstep == 3 && (isset($_POST['nbtag']) || isset($_POST['fulltxt'])))
+		if ($nextstep == 3 && isset($_POST['nbtag'])) 
 		{
-			if (!isset($_POST['fulltxt']) || !trim($_POST['fulltxt']))
-			{
-				$this->setError(JText::sprintf('COM_TOOLS_REQUIRED_FIELD_CHECK', 'Abstract'));
-				$step = 1;
-				$nextstep--;
-			}
-
-			$hztv = ToolsHelperVersion::getToolRevision($this->_toolid, $version);
+		    $hztv = Hubzero_Tool_VersionHelper::getToolRevision($this->_toolid, $version);
 
 			$objV = new ToolVersion($this->database);
-			if (!$objV->bind($_POST))
+			if (!$objV->bind($_POST)) 
 			{
 				$this->setError($objV->getError());
 				return;
 			}
 
 			$body = $this->txtClean($_POST['fulltxt']);
-			if (preg_match("/([\<])([^\>]{1,})*([\>])/i", $body))
+			if (preg_match("/([\<])([^\>]{1,})*([\>])/i", $body)) 
 			{
 				// Do nothing
 				$status['fulltxt'] = trim(stripslashes($body));
-			}
-			else
+			} 
+			else 
 			{
 				// Wiki format will be used
 				$status['fulltxt'] = JRequest::getVar('fulltxt', $status['fulltxt'], 'post');
@@ -184,7 +181,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 						$f = 'found';
 					}
 				}
-				else
+				else 
 				{
 					$f = trim($tagcontent);
 					if ($f)
@@ -194,9 +191,9 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 				}
 				$status['fulltxt'] .= '</nb:' . $tagname . '>' . "\n";
 
-				if (!$f && isset($fields[$tagname]) && $fields[$tagname]->required)
+				if (!$f && isset($fields[$tagname]) && $fields[$tagname]->required) 
 				{
-					$this->setError(JText::sprintf('COM_TOOLS_REQUIRED_FIELD_CHECK', $fields[$tagname]->label));
+					$this->setError(JText::sprintf('COM_CONTRIBUTE_REQUIRED_FIELD_CHECK', $fields[$tagname]->label));
 				}
 
 				$found[] = $tagname;
@@ -207,26 +204,27 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 				if (!in_array($field->name, $found) && $field->required)
 				{
 					$found[] = $field->name;
-					$this->setError(JText::sprintf('COM_TOOLS_REQUIRED_FIELD_CHECK', $field->label));
+					$this->setError(JText::sprintf('COM_CONTRIBUTE_REQUIRED_FIELD_CHECK', $field->label));
 				}
 			}
 
+			ximport('Hubzero_View_Helper_Html');
 			$hztv->fulltxt    = $objV->fulltxt    = $status['fulltxt'];
-			$hztv->description = $objV->description = \Hubzero\Utility\String::truncate(JRequest::getVar('description', $status['description'], 'post'), 500);
-			$hztv->title       = $objV->title       = \Hubzero\Utility\String::truncate(preg_replace('/\s+/', ' ', JRequest::getVar('title', $status['title'], 'post')), 500);
+			$hztv->description = $objV->description = Hubzero_View_Helper_Html::shortenText(JRequest::getVar('description', $status['description'], 'post'), 500, 0);
+			$hztv->title       = $objV->title       = Hubzero_View_Helper_Html::shortenText(preg_replace('/\s+/', ' ', JRequest::getVar('title', $status['title'], 'post')), 500, 0);
 
-			if (!$hztv->update())
+			if (!$hztv->update()) 
 			{
-				JError::raiseError(500, JText::_('COM_TOOLS_ERROR_UPDATING_TOOL'));
+				JError::raiseError(500, JText::_('Error updating tool tables.'));
 				return;
-			}
-			else
+			} 
+			else 
 			{
 				// get updated tool status
 				$obj->getToolStatus($this->_toolid, $this->_option, $status, $version);
 			}
 
-			if ($version == 'dev')
+			if ($version == 'dev') 
 			{
 				// update resource page
 				$this->updatePage($row->id, $status);
@@ -237,7 +235,8 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		//$accesses = array('Public', 'Registered', 'Special', 'Protected', 'Private');
 		//$lists = array();
 		//$lists['access'] = ToolsHelperHtml::selectAccess($accesses, $row->access);
-		//$groups = \Hubzero\User\Helper::getGroups($this->juser->get('id'), 'members');
+		//ximport('Hubzero_User_Helper');
+		//$groups = Hubzero_User_Helper::getGroups($this->juser->get('id'), 'members');
 
 		// get authors
 		$objA = new ToolAuthor($this->database);
@@ -249,7 +248,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 		// Get any HUB focus areas
 		// These are used where any resource is required to have one of these tags
-		$tconfig = JComponentHelper::getParams('com_tags');
+		$tconfig =& JComponentHelper::getParams('com_tags');
 		$fa1  = $tconfig->get('focus_area_01');
 		$fa2  = $tconfig->get('focus_area_02');
 		$fa3  = $tconfig->get('focus_area_03');
@@ -262,77 +261,77 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$fa10 = $tconfig->get('focus_area_10');
 
 		// Instantiate our tag object
-		$tagcloud = new ResourcesTags($row->id);
+		$tagcloud = new ResourcesTags($this->database);
 
 		// Normalize the focus areas
-		$tagfa1  = $tagcloud->normalize($fa1);
-		$tagfa2  = $tagcloud->normalize($fa2);
-		$tagfa3  = $tagcloud->normalize($fa3);
-		$tagfa4  = $tagcloud->normalize($fa4);
-		$tagfa5  = $tagcloud->normalize($fa5);
-		$tagfa6  = $tagcloud->normalize($fa6);
-		$tagfa7  = $tagcloud->normalize($fa7);
-		$tagfa8  = $tagcloud->normalize($fa8);
-		$tagfa9  = $tagcloud->normalize($fa9);
-		$tagfa10 = $tagcloud->normalize($fa10);
+		$tagfa1  = $tagcloud->normalize_tag($fa1);
+		$tagfa2  = $tagcloud->normalize_tag($fa2);
+		$tagfa3  = $tagcloud->normalize_tag($fa3);
+		$tagfa4  = $tagcloud->normalize_tag($fa4);
+		$tagfa5  = $tagcloud->normalize_tag($fa5);
+		$tagfa6  = $tagcloud->normalize_tag($fa6);
+		$tagfa7  = $tagcloud->normalize_tag($fa7);
+		$tagfa8  = $tagcloud->normalize_tag($fa8);
+		$tagfa9  = $tagcloud->normalize_tag($fa9);
+		$tagfa10 = $tagcloud->normalize_tag($fa10);
 
 		// process new tags
-		if ($tags or $tagfa)
+		if ($tags or $tagfa) 
 		{
 			$newtags = '';
-			if ($tagfa)
-			{
+			if ($tagfa) 
+			{ 
 				$newtags = $tagfa . ', ';
 			}
-			if ($tags)
-			{
+			if ($tags) 
+			{ 
 				$newtags .= $tags;
 			}
-			$tagcloud->setTags($newtags, $this->juser->get('id'));
+			$tagcloud->tag_object($this->juser->get('id'), $row->id, $newtags, 1, 0);
 		}
 
 		// Get all the tags on this resource
-		$tags_men = $tagcloud->tags();
+		$tags_men = $tagcloud->get_tags_on_object($row->id, 0, 0, 0, 0);
 		$mytagarray = array();
 		$fas = array($tagfa1, $tagfa2, $tagfa3, $tagfa4, $tagfa5, $tagfa6, $tagfa7, $tagfa8, $tagfa9, $tagfa10);
 		$fats = array();
-		if ($fa1)
+		if ($fa1) 
 		{
 			$fats[$fa1] = $tagfa1;
 		}
-		if ($fa2)
+		if ($fa2) 
 		{
 			$fats[$fa2] = $tagfa2;
 		}
-		if ($fa3)
+		if ($fa3) 
 		{
 			$fats[$fa3] = $tagfa3;
 		}
-		if ($fa4)
+		if ($fa4) 
 		{
 			$fats[$fa4] = $tagfa4;
 		}
-		if ($fa5)
+		if ($fa5) 
 		{
 			$fats[$fa5] = $tagfa5;
 		}
-		if ($fa6)
+		if ($fa6) 
 		{
 			$fats[$fa6] = $tagfa6;
 		}
-		if ($fa7)
+		if ($fa7) 
 		{
 			$fats[$fa7] = $tagfa7;
 		}
-		if ($fa8)
+		if ($fa8) 
 		{
 			$fats[$fa8] = $tagfa8;
 		}
-		if ($fa9)
+		if ($fa9) 
 		{
 			$fats[$fa9] = $tagfa9;
 		}
-		if ($fa10)
+		if ($fa10) 
 		{
 			$fats[$fa10] = $tagfa10;
 		}
@@ -340,39 +339,44 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		// Loop through all the tags and pull out the focus areas - those will be displayed differently
 		foreach ($tags_men as $tag_men)
 		{
-			if (in_array($tag_men->get('tag'), $fas))
+			if (in_array($tag_men['tag'], $fas)) 
 			{
-				$tagfa = $tag_men->get('tag');
-			}
-			else
+				$tagfa = $tag_men['tag'];
+			} 
+			else 
 			{
-				$mytagarray[] = $tag_men->get('raw_tag');
+				$mytagarray[] = $tag_men['raw_tag'];
 			}
 		}
 		$tags = implode(', ', $mytagarray);
 
+		// Push CSS to the document
+		$this->_getStyles($this->_option, 'assets/css/' . $this->_controller . '.css');
+		// Push some scripts to the document
+		$this->_getScripts('assets/js/' . $this->_controller);
+
 		// Set the document title
-		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('COM_TOOLS_EDIT_TOOL_PAGE') . ' (' . $status['toolname'] . ')';
-		$document = JFactory::getDocument();
+		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('EDIT_TOOL_PAGE') . ' (' . $status['toolname'] . ')';
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		// Set the document pathway (breadcrumbs)
-		$pathway = JFactory::getApplication()->getPathway();
-		if (count($pathway->getPathWay()) <= 0)
+		$pathway =& JFactory::getApplication()->getPathway();
+		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
-				JText::_(strtoupper($this->_name)),
+				JText::_(strtoupper($this->_name)), 
 				'index.php?option=' . $this->_option
 			);
 		}
-		if (count($pathway->getPathWay()) <= 1)
+		if (count($pathway->getPathWay()) <= 1) 
 		{
 			$pathway->addItem(
-				JText::sprintf('COM_TOOLS_STATUS_FOR', $status['toolname']),
+				JText::_('STATUS') . ' ' . JText::_('FOR') . ' ' . $status['toolname'], 
 				'index.php?option=' . $this->_option . '&controller=pipeline&task=status&app=' . $alias
 			);
 			$pathway->addItem(
-				JText::_('COM_TOOLS_EDIT_TOOL_PAGE'),
+				JText::_('EDIT_TOOL_PAGE'), 
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&app=' . $alias . '&task=start&step=1'
 			);
 		}
@@ -387,7 +391,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$this->view->authors = $authors;
 
 		// Pass error messages to the view
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -401,7 +405,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Update the associated resource page for this tool
-	 *
+	 * 
 	 * @param      integer $rid       Resource ID
 	 * @param      array   $status    Fields to update
 	 * @param      integer $published Published state
@@ -410,44 +414,44 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 	 */
 	public function updatePage($rid, $status=array(), $published=0, $newtool=0)
 	{
-		if ($rid === NULL)
+		if ($rid === NULL) 
 		{
 			return false;
 		}
 
 		$resource = new ResourcesResource($this->database);
 		$resource->load($rid);
-		if (count($status) > 0)
+		if (count($status) > 0) 
 		{
 			$resource->fulltxt    = addslashes($status['fulltxt']);
 			$resource->introtext   = $status['description'];
 			$resource->title       = preg_replace('/\s+/', ' ', $status['title']);
-			$resource->modified    = JFactory::getDate()->toSql();
+			$resource->modified    = date("Y-m-d H:i:s");
 			$resource->modified_by = $this->juser->get('id');
 		}
-		if ($published)
+		if ($published) 
 		{
 			$resource->published = $published;
 		}
-		if ($newtool && $published == 1)
+		if ($newtool && $published == 1) 
 		{
-			$resource->publish_up = JFactory::getDate()->toSql();
+			$resource->publish_up = date("Y-m-d H:i:s");
 		}
 
-		if (!$resource->store())
+		if (!$resource->store()) 
 		{
 			$this->setError($row->getError());
 			return false;
 		}
-		else if ($newtool)
+		else if ($newtool) 
 		{
-			$this->addComponentMessage(JText::_('COM_TOOLS_NOTICE_RES_PUBLISHED'));
-			//$this->setMessage(JText::_('COM_TOOLS_NOTICE_RES_PUBLISHED'));
+			$this->addComponentMessage(JText::_('NOTICE_RES_PUBLISHED'));
+			//$this->setMessage(JText::_('NOTICE_RES_PUBLISHED'));
 		}
-		else
+		else 
 		{
-			$this->addComponentMessage(JText::_('COM_TOOLS_NOTICE_RES_UPDATED'));
-			//$this->setMessage(JText::_('COM_TOOLS_NOTICE_RES_UPDATED'));
+			$this->addComponentMessage(JText::_('NOTICE_RES_UPDATED'));
+			//$this->setMessage(JText::_('NOTICE_RES_UPDATED'));
 		}
 
 		return true;
@@ -455,7 +459,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Generate a resource page from tool data
-	 *
+	 * 
 	 * @param      integer $toolid Tool ID
 	 * @param      array   $tool   Tool info to generate resource from
 	 * @return     mixed False if error, integer if success
@@ -485,7 +489,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		// Initiate extended database class
 		$row = new ResourcesResource($this->database);
 		$row->created_by = $this->juser->get('id');
-		$row->created    = JFactory::getDate()->toSql();
+		$row->created    = date('Y-m-d H:i:s');
 		$row->published  = 2;  // draft state
 		$row->params     = implode("\n", $params);
 		$row->attribs    = 'marknew=0';
@@ -494,9 +498,8 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$row->title      = $tool['title'];
 		$row->introtext  = $tool['description'];
 		$row->alias      = $tool['toolname'];
-		$row->access     = 0;
 
-		if (!$row->store())
+		if (!$row->store()) 
 		{
 			$this->setError($row->getError());
 			return false;
@@ -507,7 +510,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Preview the resource
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function previewTask()
@@ -521,7 +524,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$obj = new Tool($this->database);
 		$this->_toolid = $obj->getToolId($alias);
 
-		if (!$this->_toolid)
+		if (!$this->_toolid) 
 		{
 			// not a tool resource page
 			$this->setRedirect(
@@ -531,9 +534,9 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		}
 
 		// Make sure user is authorized to go further
-		if (!$this->_checkAccess($this->_toolid))
+		if (!$this->_checkAccess($this->_toolid)) 
 		{
-			JError::raiseError(403, JText::_('COM_TOOLS_ALERTNOTAUTH'));
+			JError::raiseError(403, JText::_('ALERTNOTAUTH'));
 			return;
 		}
 
@@ -541,20 +544,20 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$obj->getToolStatus($this->_toolid, $this->_option, $status, $version);
 
 		// Instantiate our tag object
-		$tagcloud = new ResourcesTags($rid);
+		$tagcloud = new ResourcesTags($this->database);
 		$tags  = JRequest::getVar('tags', '', 'post');
 		$tagfa = JRequest::getVar('tagfa', '', 'post');
 		// Process new tags
 		$newtags = '';
-		if ($tagfa)
+		if ($tagfa) 
 		{
 			$newtags = $tagfa . ', ';
 		}
-		if ($tags)
+		if ($tags) 
 		{
 			$newtags .= $tags;
 		}
-		$tagcloud->setTags($newtags, $this->juser->get('id'));
+		$tagcloud->tag_object($this->juser->get('id'), $rid, $newtags, 1, 1);
 
 		// Get some needed libraries
 		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'helpers' . DS . 'html.php');
@@ -563,13 +566,14 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$resource = new ResourcesResource($this->database);
 		$resource->loadAlias($alias);
 
-		if (!$this->juser->get('guest'))
+		if (!$this->juser->get('guest')) 
 		{
-			$xgroups = \Hubzero\User\Helper::getGroups($this->juser->get('id'), 'all');
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($this->juser->get('id'), 'all');
 			// Get the groups the user has access to
 			$usersgroups = $this->_getUsersGroups($xgroups);
-		}
-		else
+		} 
+		else 
 		{
 			$usersgroups = array();
 		}
@@ -581,37 +585,44 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$thistool = $thistool ? $thistool[0] : '';
 
 		// Replace resource info with requested version
-		$objV->compileResource($thistool, '', $resource, 'dev', $this->rconfig);
+		$objV->compileResource($thistool, '', &$resource, 'dev', $this->rconfig);
 
 		// get language library
-		$lang = JFactory::getLanguage();
-		if (!$lang->load(strtolower('com_resources'), JPATH_BASE))
+		$lang =& JFactory::getLanguage();
+		if (!$lang->load(strtolower('com_resources'), JPATH_BASE)) 
 		{
-			$this->setError(JText::_('COM_TOOLS_ERROR_LOADING_LANGUAGE'));
+			$this->setError(JText::_('Failed to load language file'));
 		}
 
+		// Push CSS to the document
+		$this->_getStyles($this->_option, 'assets/css/' . $this->_controller . '.css');
+
+		// Push some scripts to the document
+		$this->_getScripts('assets/js/' . $this->_controller);
+		$this->_getStyles('com_resources');
+
 		// Set the document title
-		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('COM_TOOLS_PREVIEW_TOOL_PAGE') . ' (' . $resource->alias . ')';
-		$document = JFactory::getDocument();
+		$this->view->title = JText::_(strtoupper($this->_name)) . ': ' . JText::_('PREVIEW_TOOL_PAGE') . ' (' . $resource->alias . ')';
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->view->title);
 
 		// Set the document pathway (breadcrumbs)
-		$pathway = JFactory::getApplication()->getPathway();
-		if (count($pathway->getPathWay()) <= 0)
+		$pathway =& JFactory::getApplication()->getPathway();
+		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
-				JText::_(strtoupper($this->_name)),
+				JText::_(strtoupper($this->_name)), 
 				'index.php?option=' . $this->_option
 			);
 		}
-		if (count($pathway->getPathWay()) <= 1)
+		if (count($pathway->getPathWay()) <= 1) 
 		{
 			$pathway->addItem(
-				JText::sprintf('COM_TOOLS_STATUS_FOR', $thistool->toolname),
+				JText::_('STATUS') . ' ' . JText::_('FOR') . ' ' . $thistool->toolname, 
 				'index.php?option=' . $this->_option . '&controller=pipeline&task=status&app=' . $alias
 			);
 			$pathway->addItem(
-				JText::_('COM_TOOLS_EDIT_TOOL_PAGE'),
+				JText::_('EDIT_TOOL_PAGE'), 
 				'index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&app=' . $alias . '&task=start&step=1'
 			);
 		}
@@ -625,7 +636,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$this->view->status      = $status;
 
 		// Pass error messages to the view
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -639,7 +650,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Strip some unwanted and potentially harmful items out of text
-	 *
+	 * 
 	 * @param      string &$text Text to clean
 	 * @return     string
 	 */
@@ -655,18 +666,18 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Push a user's groups' alias to an array for easier searching
-	 *
+	 * 
 	 * @param      array $groups User's groups
 	 * @return     array
 	 */
 	private function _getUsersGroups($groups)
 	{
 		$arr = array();
-		if (!empty($groups))
+		if (!empty($groups)) 
 		{
 			foreach ($groups as $group)
 			{
-				if ($group->regconfirmed)
+				if ($group->regconfirmed) 
 				{
 					$arr[] = $group->cn;
 				}
@@ -677,7 +688,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Check if the current user has access to this tool
-	 *
+	 * 
 	 * @param      unknown $toolid       Tool ID
 	 * @param      integer $allowAdmins  Allow admins access?
 	 * @param      boolean $allowAuthors Allow authors access?
@@ -689,17 +700,17 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		$obj = new Tool($this->database);
 
 		// allow to view if admin
-		if ($this->config->get('access-manage-component') && $allowAdmins)
+		if ($this->config->get('access-manage-component') && $allowAdmins) 
 		{
 			return true;
 		}
 
 		// check if user in tool dev team
-		if ($developers = $obj->getToolDevelopers($toolid))
+		if ($developers = $obj->getToolDevelopers($toolid)) 
 		{
-			foreach ($developers as $dv)
+			foreach ($developers as $dv) 
 			{
-				if ($dv->uidNumber == $this->juser->get('id'))
+				if ($dv->uidNumber == $this->juser->get('id')) 
 				{
 					return true;
 				}
@@ -707,7 +718,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 		}
 
 		// allow access to tool authors
-		if ($allowAuthors)
+		if ($allowAuthors) 
 		{
 			// Nothing here?
 		}
@@ -717,7 +728,7 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 
 	/**
 	 * Authorization checks
-	 *
+	 * 
 	 * @param      string $assetType Asset type
 	 * @param      string $assetId   Asset id to check against
 	 * @return     void
@@ -725,23 +736,24 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 	protected function _authorize($assetType='component', $assetId=null)
 	{
 		$this->config->set('access-view-' . $assetType, true);
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			return;
 		}
 
 		// if no admin group is defined, allow superadmin to act as admin
 		// otherwise superadmins can only act if they are also a member of the component admin group
-		if (($admingroup = trim($this->config->get('admingroup', ''))))
+		if (($admingroup = trim($this->config->get('admingroup', '')))) 
 		{
+			ximport('Hubzero_User_Helper');
 			// Check if they're a member of admin group
-			$ugs = \Hubzero\User\Helper::getGroups($this->juser->get('id'));
-			if ($ugs && count($ugs) > 0)
+			$ugs = Hubzero_User_Helper::getGroups($this->juser->get('id'));
+			if ($ugs && count($ugs) > 0) 
 			{
 				$admingroup = strtolower($admingroup);
 				foreach ($ugs as $ug)
 				{
-					if (strtolower($ug->cn) == $admingroup)
+					if (strtolower($ug->cn) == $admingroup) 
 					{
 						$this->config->set('access-manage-' . $assetType, true);
 						$this->config->set('access-admin-' . $assetType, true);
@@ -752,30 +764,44 @@ class ToolsControllerResource extends \Hubzero\Component\SiteController
 				}
 			}
 		}
-		else
+		else 
 		{
-			$asset  = $this->_option;
-			if ($assetId)
+			if (version_compare(JVERSION, '1.6', 'ge'))
 			{
-				$asset .= ($assetType != 'component') ? '.' . $assetType : '';
-				$asset .= ($assetId) ? '.' . $assetId : '';
-			}
+				$asset  = $this->_option;
+				if ($assetId)
+				{
+					$asset .= ($assetType != 'component') ? '.' . $assetType : '';
+					$asset .= ($assetId) ? '.' . $assetId : '';
+				}
 
-			$at = '';
-			if ($assetType != 'component')
+				$at = '';
+				if ($assetType != 'component')
+				{
+					$at .= '.' . $assetType;
+				}
+
+				// Admin
+				$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
+				$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
+				// Permissions
+				$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
+				$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
+				$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
+				$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
+				$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
+			}
+			else 
 			{
-				$at .= '.' . $assetType;
+				if ($this->juser->authorize($this->_option, 'manage'))
+				{
+					$this->config->set('access-manage-' . $assetType, true);
+					$this->config->set('access-admin-' . $assetType, true);
+					$this->config->set('access-create-' . $assetType, true);
+					$this->config->set('access-delete-' . $assetType, true);
+					$this->config->set('access-edit-' . $assetType, true);
+				}
 			}
-
-			// Admin
-			$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
-			$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
-			// Permissions
-			$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
-			$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
-			$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
-			$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
-			$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
 		}
 	}
 }
