@@ -764,7 +764,8 @@ class ToolsControllerSessions extends Hubzero_Controller
 		$dispatcher->trigger('onAfterSessionStart', array($toolname, $tv->revision));
 
 		// Set the layout
-		$this->view->setLayout('session');
+		$sublayout = strtolower(JRequest::getWord('layout', ''));
+		$this->view->setLayout('session' . ($sublayout ? '_' . $sublayout : ''));
 
 		// Set the page title
 		$title  = JText::_('Resources').': '.JText::_('Tools');
