@@ -31,14 +31,30 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
+
 /**
  * XMessage plugin class for email
  */
-class plgXMessageEmail extends \Hubzero\Plugin\Plugin
+class plgXMessageEmail extends JPlugin
 {
+	/**
+	 * Constructor
+	 * 
+	 * @param      object &$subject Event observer
+	 * @param      array  $config   Optional config values
+	 * @return     void
+	 */
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
+
 	/**
 	 * Return this messaging type
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function onMessageMethods()
@@ -48,7 +64,7 @@ class plgXMessageEmail extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Send a message to a user
-	 *
+	 * 
 	 * @param      array   $from     Message 'from' data (e.g., name, address)
 	 * @param      object  $xmessage The message to send
 	 * @param      object  $user     User to send the message to
@@ -57,108 +73,76 @@ class plgXMessageEmail extends \Hubzero\Plugin\Plugin
 	 */
 	public function onMessage($from, $xmessage, $user, $action)
 	{
-		//make sure were supposed to be performing this action
-		if ($this->onMessageMethods() != $action)
+		if ($this->onMessageMethods() != $action) 
 		{
 			return true;
 		}
 
-		//check to make sure users account is confirmed
-		if ($user->get('emailConfirmed') <= 0)
+		if ($user->get('emailConfirmed') <= 0) 
 		{
 			return false;
 		}
 
-		//if we dont have an email stop
-		if (!$user->get('email'))
+		$email = $user->get('email');
+
+		if (!$email) 
 		{
 			return false;
 		}
 
-		// get site config
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 
-		// if we dont have a from set the use site from name and email
-		if (!isset($from['name']) || $from['name'] == '')
+		if (!isset($from['name']) || $from['name'] == '') 
 		{
 			$from['name'] = $jconfig->getValue('config.sitename') . ' Administrator';
 		}
-		if (!isset($from['email']) || $from['email'] == '')
+		if (!isset($from['email']) || $from['email'] == '') 
 		{
 			$from['email'] = $jconfig->getValue('config.mailfrom');
 		}
 
-		$message = new \Hubzero\Mail\Message();
-		$message->setSubject($jconfig->getValue('config.sitename') . ' ' . $xmessage->subject)
-		        ->addFrom($from['email'], $from['name'])
-		        ->addTo($user->get('email'), $user->get('name'));
+		$args = "-f '" . $from['email'] . "'";
+		$headers = "MIME-Version: 1.0\n";
+		$headers .= "Content-type: text/plain; charset=utf-8\n";
+		$headers .= "From: " . $from['name'] . " <" . $from['email'] . ">\n";
 
 		// In case a different reply to email address is specified
 		if (array_key_exists('replytoemail', $from))
 		{
-			$replytoname = (isset($from['replytoname']) && $from['replytoname'] != '') ? $from['replytoname'] : $from['name'];
-
-			$message->addReplyTo($from['replytoemail'], $replytoname);
+			$headers .= "Reply-To: " . $from['name'] . " <" . $from['replytoemail'] . ">\n";
 		}
 		else
 		{
-			$message->addReplyTo($from['email'], $from['name']);
+			$headers .= "Reply-To: " . $from['name'] . " <" . $from['email'] . ">\n";
 		}
 
-		//set mail additional args (mail return path - used for bounces)
-		$message->addHeader('X-Component', $xmessage->component)
-		        ->addHeader('X-Component-Object', $xmessage->type);
+		$headers .= "X-Priority: 3\n";
+		$headers .= "X-MSMail-Priority: High\n";
+		$headers .= "X-Mailer: " . $from['name'] . "\n";
 
-		// Want to add some extra headers? We put them into the from array
+		if( strpos($user->get('name'), ',') )
+			$fullEmailAddress = "\"" . $user->get('name') . "\" <" . $user->get('email') . ">";
+		else
+			$fullEmailAddress = $user->get('name') . " <" . $user->get('email') . ">";
+
+		// Want to add some extra headers? We put them into the from array 
 		// If none are there, this breaks nothing
-		if (array_key_exists('xheaders', $from))
+        if (array_key_exists('xheaders', $from))
 		{
+			$hs = $from['xheaders'];
+
 			// The xheaders array has name and value pairs
-			foreach ($from['xheaders'] as $n => $v)
+			foreach($hs as $n => $v)
 			{
-				$message->addHeader($n, $v);
+				$headers .= $n . ": " . $v . "\n";
 			}
 		}
 
-		if (is_array($xmessage->message))
-		{
-			if (isset($xmessage->message['attachments']))
-			{
-				if (!is_array($xmessage->message['attachments']))
-				{
-					$xmessage->message['attachments'] = array($xmessage->message['attachments']);
-				}
-				foreach ($xmessage->message['attachments'] as $path)
-				{
-					if (preg_match("/\.(bmp|gif|jpg|jpe|jpeg|png)$/i", $path))
-					{
-						$file = basename($path);
-						$xmessage->message['multipart'] = preg_replace(
-							'/<a class="img" data\-filename="' . str_replace('.', '\.', $file) . '" href="(.*?)"\>(.*?)<\/a>/i',
-							'<img src="' . $message->getEmbed($path) . '" alt="" />',
-							$xmessage->message['multipart']
-						);
-					}
-					else
-					{
-						$message->addAttachment($path);
-					}
-				}
-			}
-
-			$message->addPart($xmessage->message['plaintext'], 'text/plain')
-			        ->addPart($xmessage->message['multipart'], 'text/html');
-		}
-		else
-		{
-			$message->setBody($xmessage->message);
-		}
-
-		// send mail
-		if ($message->send())
+		if (mail($fullEmailAddress, $jconfig->getValue('config.sitename').' '.$xmessage->subject, $xmessage->message, $headers, $args))
 		{
 			return true;
 		}
+
 		return false;
 	}
 }
